@@ -17,11 +17,8 @@
 
 from typing import Any
 
-from typing_extensions import deprecated
-
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from selenium.webdriver.common.options import ArgOptions
-from selenium.webdriver.firefox.firefox_binary import FirefoxBinary
 from selenium.webdriver.firefox.firefox_profile import FirefoxProfile
 
 
@@ -48,20 +45,6 @@ class Options(ArgOptions):
         self._profile: FirefoxProfile | None = None
         self.log = Log()
 
-    @property
-    @deprecated("use binary_location instead")
-    def binary(self) -> FirefoxBinary:
-        """Returns the FirefoxBinary instance."""
-        return FirefoxBinary(self._binary_location)
-
-    @binary.setter
-    @deprecated("use binary_location instead")
-    def binary(self, new_binary: str | FirefoxBinary) -> None:
-        """Set location of browser binary (string or FirefoxBinary instance)."""
-        if isinstance(new_binary, FirefoxBinary):
-            new_binary = new_binary._start_cmd
-        self.binary_location = str(new_binary)
-
     @property
     def binary_location(self) -> str:
         """Returns the location of the binary."""
