@@ -15,18 +15,21 @@
 # specific language governing permissions and limitations
 # under the License.
 
+import logging
+import os
+import sys
 from collections.abc import Mapping, Sequence
+from typing import IO, Any
 
-from selenium.types import SubprocessStdAlias
 from selenium.webdriver.common import service, utils
 
 
 class Service(service.Service):
-    """Service class responsible for starting and stopping geckodriver.
+    """Service class responsible for starting and stopping of `geckodriver`.
 
     Args:
-        executable_path: install path of the geckodriver executable, defaults to `geckodriver`.
-        port: Port for the service to run on, defaults to 0 where the operating system will decide.
+        executable_path: (Optional) Install path of the executable.
+        port: (Optional) Port for the service to run on, defaults to 0 where the operating system will decide.
         service_args: (Optional) Sequence of args to be passed to the subprocess when launching the executable.
         log_output: (Optional) int representation of STDOUT/DEVNULL, any IO instance or String path to file.
         env: (Optional) Mapping of environment variables for the new process, defaults to `os.environ`.
@@ -38,7 +41,7 @@ class Service(service.Service):
         executable_path: str | None = None,
         port: int = 0,
         service_args: Sequence[str] | None = None,
-        log_output: SubprocessStdAlias | None = None,
+        log_output: int | str | IO[Any] | None = None,
         env: Mapping[str, str] | None = None,
         driver_path_env_key: str | None = None,
         **kwargs,
@@ -46,6 +49,24 @@ class Service(service.Service):
         self._service_args = list(service_args or [])
         driver_path_env_key = driver_path_env_key or "SE_GECKODRIVER"
 
+        if os.environ.get("SE_DEBUG"):
+            has_log_arg = "--log" in self._service_args or any(arg.startswith("--log=") for arg in self._service_args)
+            has_output_conflict = log_output is not None
+            if has_log_arg or has_output_conflict:
+                logging.getLogger(__name__).warning(
+                    "Environment Variable `SE_DEBUG` is set; "
+                    "forcing GeckoDriver log level to DEBUG and overriding configured log level/output."
+                )
+            if has_log_arg:
+                if "--log" in self._service_args:
+                    idx = self._service_args.index("--log")
+                    del self._service_args[idx : idx + 2]
+                else:
+                    self._service_args = [arg for arg in self._service_args if not arg.startswith("--log=")]
+            self._service_args.append("--log")
+            self._service_args.append("debug")
+            log_output = sys.stderr
+
         super().__init__(
             executable_path=executable_path,
             port=port,
