@@ -692,19 +692,16 @@ def new_window_is_opened(current_handles: set[str]) -> Callable[[WebDriver], boo
     return _predicate
 
 
-def alert_is_present() -> Callable[[WebDriver], Alert | bool]:
+def alert_is_present() -> Callable[[WebDriver], Alert | Literal[False]]:
     """Check that an alert is present and switch to it.
 
     Returns:
-        The Alert once it is located.
+        The Alert once it is located, or False if no alert is present.
 
     Example:
         from selenium.webdriver.support.ui import WebDriverWait
         from selenium.webdriver.support import expected_conditions as EC
         alert = WebDriverWait(driver, 10).until(EC.alert_is_present())
-
-    Note:
-        If the alert is present it switches the given driver to it.
     """
 
     def _predicate(driver: WebDriver):
